# Project viewer
Project viewer is a tool that provides you with many kind of metric visualizations of your git repository.

With Project viewer you can:

- See who worked on different parts of the project
- Get an overview of the file structure
- See where there is the most activity in your project
- See how your project has looked at different points in time
	
Where has the most work been done recently? 	Who worked on different subsystems in the past?

You can read more about the features in the feature overview, or just try it and start exploring your projects!

## Get started:

- In your terminal, navigate to a git repository or a folder containing any repository
- Run the command "project-viewer ." (if in a repository base folder, otherwise explicitly submit the base repository folder of your project)
- The application will now open in your default browser.

## Note

To use Project viewer, you will need to have the following programs installed:

    Python interpreter version >= 3.10
    git 2.29 or newer

Check your installed versions using **python --version**, **pip --version** and **git --version**.

## What makes Project viewer different?

🔒 Private by design

🏝️ Works offline

🤷 Git provider agnostic - works with any git repository

😊 No tracking, no ads, no cloud, no servers, no subscription